import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';
import calendarize from 'calendarize';
import { __spread, __rest, __assign } from 'tslib';
import { Component, EventEmitter, Input, Output, ElementRef, HostListener, Pipe, NgModule } from '@angular/core';
import dayjs from 'dayjs';
import isSameOrAfter from 'dayjs/plugin/isSameOrAfter';
import isSameOrBefore from 'dayjs/plugin/isSameOrBefore';
import customParser from 'dayjs/plugin/customParseFormat';

var DateRange = (function () {
    function DateRange() {
    }
    return DateRange;
}());
var DateChanged = (function () {
    function DateChanged() {
    }
    return DateChanged;
}());
var YearMonthChanged = (function () {
    function YearMonthChanged() {
    }
    return YearMonthChanged;
}());
var MonthNameValue = (function () {
    function MonthNameValue() {
    }
    return MonthNameValue;
}());
var DefinedDateRange = (function () {
    function DefinedDateRange() {
    }
    return DefinedDateRange;
}());
var Timepicker = (function () {
    function Timepicker() {
        this.minuteInterval = 1;
        this.twentyFourHourFormat = true;
    }
    return Timepicker;
}());
var YearsGrid = (function () {
    function YearsGrid() {
    }
    return YearsGrid;
}());
var Options = (function () {
    function Options() {
        this.startDate = null;
        this.endDate = null;
        this.minDate = null;
        this.maxDate = null;
        this.format = 'YYYY-MM-DD';
        this.inactiveBeforeStart = false;
        this.autoApply = false;
        this.singleCalendar = false;
        this.noDefaultRangeSelected = false;
        this.showRanges = false;
        this.position = 'left';
        this.disabled = false;
        this.timePicker = null;
        this.disableBeforeStart = false;
        this.alwaysOpen = false;
        this.theme = 'light';
        this.required = false;
        this.DOB = false;
        this.weekStartsOn = 0;
        this.addTouchSupport = false;
        this.placeholder = '';
        this.hideControls = false;
        this.readOnly = false;
        this.disableWeekEnds = false;
        this.disabledDays = null;
        this.disabledDates = null;
    }
    return Options;
}());

dayjs.extend(isSameOrAfter);
dayjs.extend(isSameOrBefore);
dayjs.extend(customParser);
var Calendar = (function () {
    function Calendar() {
        this.maxMonth = 0;
        this.maxYear = 0;
        this.minYear = 0;
        this.minMonth = 0;
        this.srFormat = 'DD MMMM YYYY hh:mm a';
        this.dateChanged = new EventEmitter();
        this.monthChanged = new EventEmitter();
        this.yearChanged = new EventEmitter();
        this.scrollTop = new EventEmitter();
        this.isTouch = false;
        this.monthsList = [];
        this.yearsList = [];
    }
    Object.defineProperty(Calendar.prototype, "monthText", {
        get: function () {
            return dayjs()
                .set('year', +this.year)
                .set('month', +this.month)
                .format('MMM');
        },
        enumerable: true,
        configurable: true
    });
    Calendar.prototype.ngOnChanges = function () {
        this.isTouch =
            this.addTouchSupport && !window.matchMedia('(hover: hover)').matches;
        this.maxYear = this.maxDate ? this.maxDate.get('year') : 100000;
        this.maxMonth = this.maxDate ? this.maxDate.get('month') : 12;
        this.minYear = this.minDate ? this.minDate.get('year') : 0;
        this.minMonth = this.minDate ? this.minDate.get('month') : -1;
        this.createCalendarGridData();
    };
    Calendar.prototype.getNextMonthFirstWeek = function () {
        var thisMonthStartDate = dayjs()
            .set('year', +this.year)
            .set('month', +this.month)
            .startOf('month');
        var nextMonthStartDate = thisMonthStartDate
            .add(1, 'month')
            .startOf('month');
        var year = nextMonthStartDate.get('year');
        var month = nextMonthStartDate.get('month');
        return calendarize(nextMonthStartDate.toDate(), this.weekStartsOn)
            .shift()
            .filter(Boolean)
            .map((function (day) {
            return dayjs()
                .set('year', year)
                .set('month', month)
                .set('date', day)
                .set('hour', 0)
                .set('minute', 0)
                .set('second', 0)
                .set('millisecond', 0);
        }));
    };
    Calendar.prototype.getPreviousMonthNthLastWeek = function (nthLastCount) {
        var thisMonthStartDate = dayjs()
            .set('year', +this.year)
            .set('month', +this.month)
            .startOf('month');
        var previousMonthStartDate = thisMonthStartDate
            .subtract(1, 'month')
            .startOf('month');
        var year = previousMonthStartDate.get('year');
        var month = previousMonthStartDate.get('month');
        return calendarize(previousMonthStartDate.toDate(), this.weekStartsOn)
            .slice(-nthLastCount)[0]
            .filter(Boolean)
            .map((function (day) {
            return dayjs()
                .set('year', year)
                .set('month', month)
                .set('date', day)
                .set('hour', 0)
                .set('minute', 0)
                .set('second', 0)
                .set('millisecond', 0);
        }));
    };
    Calendar.prototype.createTouchCalendarGridData = function () {
        var monthsList = [
            'January',
            'February',
            'March',
            'April',
            'May',
            'June',
            'July',
            'August',
            'September',
            'October',
            'November',
            'December',
        ];
        this.yearsList = [];
        this.monthsList = [];
        for (var i = 1900; i <= +dayjs().add(100, 'year').get('year'); i++) {
            if (i < this.minYear || i > this.maxYear) {
                continue;
            }
            this.yearsList.push(i);
        }
        for (var i = 0; i < monthsList.length; i++) {
            if (this.year === this.minYear && i < this.minMonth) {
                continue;
            }
            if (this.year === this.maxYear && i > this.maxMonth) {
                continue;
            }
            this.monthsList.push({
                name: monthsList[i],
                value: i,
            });
        }
    };
    Calendar.prototype.createCalendarGridData = function () {
        if (this.year <= this.minYear && this.month < this.minMonth) {
            this.year = this.minYear;
            this.month = this.minMonth;
        }
        if (this.year >= this.maxYear && this.month > this.maxMonth) {
            this.year = this.maxYear;
            this.month = this.maxMonth;
        }
        var year = null;
        var month = null;
        this.setWeekDays();
        this.setWeekEnd();
        var thisMonthStartDate = dayjs()
            .set('year', +this.year)
            .set('month', +this.month)
            .startOf('month');
        year = thisMonthStartDate.get('year');
        month = thisMonthStartDate.get('month');
        var thisMonthWeekList = calendarize(thisMonthStartDate.toDate(), this.weekStartsOn).map((function (week) {
            return week.filter(Boolean).map((function (day) {
                if (day === 0) {
                    return null;
                }
                return dayjs()
                    .set('year', year)
                    .set('month', month)
                    .set('date', day)
                    .set('hour', 0)
                    .set('minute', 0)
                    .set('second', 0)
                    .set('millisecond', 0);
            }));
        }));
        if (!this.isTouch) {
            if (thisMonthWeekList[0].length < 7) {
                thisMonthWeekList[0] = this.getPreviousMonthNthLastWeek(1).concat(thisMonthWeekList[0]);
            }
            if (thisMonthWeekList.slice(-1)[0].length < 7) {
                thisMonthWeekList[thisMonthWeekList.length - 1] = thisMonthWeekList.slice(-1)[0].concat(this.getNextMonthFirstWeek());
            }
            if (thisMonthWeekList.length < 6) {
                thisMonthWeekList.unshift(this.getPreviousMonthNthLastWeek(2));
            }
        }
        else {
            this.createTouchCalendarGridData();
        }
        this.weekList = thisMonthWeekList;
    };
    Calendar.prototype.setWeekEnd = function () {
        this.weekEndOn = [this.weekStartsOn, this.weekStartsOn + 6];
    };
    Calendar.prototype.setWeekDays = function () {
        var weekDays = ['Su', 'Mo', 'Tu', 'We', 'Th', 'Fr', 'Sa'];
        weekDays = __spread(weekDays.slice(this.weekStartsOn, 7), weekDays.slice(0, this.weekStartsOn));
        this.weekDays = weekDays;
    };
    Calendar.prototype.isDisabled = function (day) {
        if (this.disableWeekEnds && this.weekEndOn.includes(day.get('day'))) {
            return true;
        }
        if (this.disabledDays && this.disabledDays.includes(day.get('day'))) {
            return true;
        }
        if (this.disabledDates &&
            this.disabledDates.find((function (x) { return x.isSame(day, 'date'); }))) {
            return true;
        }
        if (this.disableBeforeStart && !this.isLeft) {
            return day.isBefore(this.selectedFromDate);
        }
        return day.isBefore(this.minDate) || day.isAfter(this.maxDate);
    };
    Calendar.prototype.isDateAvailable = function (day) {
        if (day.get('month') !== this.month) {
            return false;
        }
        if (!this.singleCalendar &&
            this.inactiveBeforeStart &&
            day.isBefore(this.selectedFromDate, 'date')) {
            return false;
        }
        return true;
    };
    Calendar.prototype.isSelectedDate = function (day) {
        if (day.get('month') === this.month &&
            day.isSame(this.selectedFromDate, 'date')) {
            return true;
        }
        if (!this.singleCalendar &&
            day.get('month') === this.month &&
            day.isSameOrAfter(this.selectedFromDate, 'date') &&
            day.isSameOrBefore(this.selectedToDate, 'date')) {
            return true;
        }
    };
    Calendar.prototype.getFormattedDate = function (day) {
        return day.format(this.format);
    };
    Calendar.prototype.scrollMeOutTop = function () {
        this.scrollTop.emit();
    };
    Calendar.prototype.dateSelected = function (day) {
        this.dateChanged.emit({
            day: day,
            isLeft: this.isLeft,
        });
    };
    Calendar.prototype.monthSelected = function (value) {
        this.monthChanged.emit({
            value: value,
            isLeft: this.isLeft,
        });
    };
    Calendar.prototype.yearSelected = function (value) {
        if (value) {
            this.yearChanged.emit({
                value: value,
                isLeft: this.isLeft,
            });
        }
    };
    Calendar.decorators = [
        { type: Component, args: [{
                    selector: 'calendar',
                    template: "<div *ngIf=\"!isTouch\" class=\"drp-flex drp-space-around\">\n  <button class=\"drp-btn flat\" (click)=\"yearSelected(year-1)\" title=\"Previous year\" aria-label=\"Previous year\"\n    [disabled]=\"year === minYear\">\n    <doublechevronleft></doublechevronleft>\n  </button>\n  <button class=\"drp-btn flat\" (click)=\"monthSelected(-1)\" title=\"Previous month\" aria-label=\"Previous month\"\n    [disabled]=\"year === minYear && month === minMonth\">\n    <chevronleft></chevronleft>\n  </button>\n  <label class=\"mb-0\"> {{monthText}} {{year}} </label>\n  <button class=\"drp-btn flat next\" (click)=\"monthSelected(1)\" title=\"Next month\" aria-label=\"Next month\"\n    [disabled]=\"year === maxYear && month === maxMonth\">\n    <chevronleft></chevronleft>\n  </button>\n  <button class=\"drp-btn flat next\" (click)=\"yearSelected(year+1)\" title=\"Next Year\" aria-label=\"Next Year\"\n    [disabled]=\"year === maxYear\">\n    <doublechevronleft></doublechevronleft>\n  </button>\n</div>\n<div [ngClass]=\"{\n  'drp-flex': isTouch\n}\">\n  <div *ngIf=\"!isTouch\" class=\"drp-calendar-row\">\n    <span *ngFor=\"let day of weekDays\" class=\"day\">{{ day }}</span>\n  </div>\n  <div class=\"drp-flex drp-column drp-calendar-column years\" *ngIf=\"isTouch\">\n    <div class=\"drp-calendar-row\" *ngFor=\"let y of yearsList; let i=index\">\n      <span (click)=\"yearSelected(y)\" [class.active]=\"year === y\">\n        <button class=\"drp-btn flat\" [attr.aria-label]=\"y\">{{ y }}</button>\n      </span>\n    </div>\n  </div>\n  <div class=\"drp-flex drp-column drp-calendar-column months\" *ngIf=\"isTouch\">\n    <div class=\"drp-calendar-row\" *ngFor=\"let m of monthsList;\">\n      <span (click)=\"monthSelected(m.value)\" [class.active]=\"month === m.value\">\n        <button class=\" drp-btn flat\" [attr.aria-label]=\"m.name\">{{ m.name }}</button>\n      </span>\n    </div>\n  </div>\n  <div class=\"drp-flex drp-column drp-calendar-column\">\n    <div class=\"drp-calendar-row\" *ngFor=\"let week of weekList; let i=index\">\n      <span *ngFor=\"let day of weekList[i]\" (click)=\"dateSelected(day)\"\n        [ngClass]=\"{'off':!isDateAvailable(day),'active':isSelectedDate(day),'disabled':isDisabled(day)}\">\n        <button class=\"drp-btn flat\" [disabled]=\"isDisabled(day)\"\n          [attr.aria-label]=\"day | formatDate: srFormat\">{{ !isTouch ? day.format('D') : day.format('ddd D') }}</button>\n      </span>\n    </div>\n  </div>\n</div>\n<timepicker *ngIf=\"timePicker\" [options]=\"timePicker\" [selectedFromDate]=\"selectedFromDate\"\n  [selectedToDate]=\"selectedToDate\" [minDate]=\"minDate\" [maxDate]=\"maxDate\" [format]=\"format\" [isLeft]=\"isLeft\"\n  (timeChanged)=\"dateSelected($event)\">\n</timepicker>\n<button *ngIf=\"isTouch\" (click)=\"scrollMeOutTop()\" class=\"drp-btn flat next drp-next-calendar-cta\" title=\"Set\"\n  aria-label=\"Set\">\n  SET <chevronleft></chevronleft>\n</button>\n"
                }] }
    ];
    Calendar.propDecorators = {
        month: [{ type: Input }],
        year: [{ type: Input }],
        selectedFromDate: [{ type: Input }],
        selectedToDate: [{ type: Input }],
        isLeft: [{ type: Input }],
        format: [{ type: Input }],
        minDate: [{ type: Input }],
        maxDate: [{ type: Input }],
        inactiveBeforeStart: [{ type: Input }],
        disableBeforeStart: [{ type: Input }],
        timePicker: [{ type: Input }],
        singleCalendar: [{ type: Input }],
        weekStartsOn: [{ type: Input }],
        addTouchSupport: [{ type: Input }],
        disabledDates: [{ type: Input }],
        disabledDays: [{ type: Input }],
        disableWeekEnds: [{ type: Input }],
        dateChanged: [{ type: Output }],
        monthChanged: [{ type: Output }],
        yearChanged: [{ type: Output }],
        scrollTop: [{ type: Output }]
    };
    return Calendar;
}());

var defaults = {
    ranges: [
        {
            name: 'Today',
            value: {
                start: dayjs().startOf('day'),
                end: dayjs().endOf('day'),
            },
        },
        {
            name: 'Yesterday',
            value: {
                start: dayjs().subtract(1, 'day').startOf('day'),
                end: dayjs().subtract(1, 'day').endOf('day'),
            },
        },
        {
            name: 'This week',
            value: {
                start: dayjs().startOf('week'),
                end: dayjs().endOf('week'),
            },
        },
        {
            name: 'This month',
            value: {
                start: dayjs().startOf('month'),
                end: dayjs().endOf('month'),
            },
        },
        {
            name: 'Last Month',
            value: {
                start: dayjs().subtract(1, 'month').startOf('month'),
                end: dayjs().subtract(1, 'month').endOf('month'),
            },
        },
    ],
};

var isTouch = !window.matchMedia('(hover: hover)').matches;
function isLargeDesktop() {
    return window.matchMedia('(min-width: 1000px)').matches;
}

dayjs.extend(isSameOrAfter);
dayjs.extend(isSameOrBefore);
dayjs.extend(customParser);
var Daterangepicker = (function () {
    function Daterangepicker(elem) {
        this.elem = elem;
        this.rangeSelected = new EventEmitter();
        this.range = '';
        this.enableApplyButton = false;
        this.areOldDatesStored = false;
        this.isLargeDesktop = false;
    }
    Daterangepicker.prototype.handleOutsideClick = function (event) {
        console.log(event);
        if (!this.derivedOptions.disabled) {
            var current = event.target;
            var host = this.elem.nativeElement;
            if (host.compareDocumentPosition(current) &
                window.Node.DOCUMENT_POSITION_CONTAINED_BY) {
                if (event.key === 'Escape') {
                    return this.toggleCalendars(false);
                }
                this.storeOldDates();
                return this.toggleCalendars(true);
            }
            if (this.showCalendars) {
                if (!this.derivedOptions.autoApply) {
                    this.restoreOldDates();
                }
                return this.toggleCalendars(false);
            }
        }
    };
    Daterangepicker.prototype.ngDoCheck = function () {
        this.deriveOptions(true);
    };
    Daterangepicker.prototype.ngOnChanges = function () {
        this.initialize();
    };
    Daterangepicker.prototype.ngOnInit = function () {
        var _this = this;
        this.initialize();
        window.onresize = (function () {
            _this.isLargeDesktop = isLargeDesktop();
        });
        this.elem.nativeElement.setAttribute('class', '');
    };
    Daterangepicker.prototype.initialize = function () {
        this.deriveOptions();
        this.validateMinMaxDates();
        this.setFromDate(this.derivedOptions.startDate);
        this.setToDate(this.derivedOptions.endDate);
        this.updateCalendar();
    };
    Daterangepicker.prototype.deriveOptions = function (isUpdate) {
        if (isUpdate === void 0) { isUpdate = false; }
        if (isUpdate) {
            var _a = this.options, startDate = _a.startDate, endDate = _a.endDate, minDate = _a.minDate, maxDate = _a.maxDate, restOptions = __rest(_a, ["startDate", "endDate", "minDate", "maxDate"]);
            this.derivedOptions = __assign({}, new Options(), this.derivedOptions, restOptions);
        }
        else {
            this.derivedOptions = __assign({}, new Options(), this.options);
        }
        this.isLargeDesktop = isLargeDesktop();
        if (isNaN(this.fromMonth)) {
            this.fromMonth = dayjs().get('month');
        }
        if (isNaN(this.fromYear)) {
            this.fromYear = dayjs().get('year');
        }
        if (isNaN(this.toMonth)) {
            this.toMonth = dayjs().get('month');
        }
        if (isNaN(this.toYear)) {
            this.toYear = dayjs().get('year');
        }
        this.derivedOptions.weekStartsOn =
            Math.abs(this.derivedOptions.weekStartsOn) % 7;
        if (this.derivedOptions.noDefaultRangeSelected) {
            this.derivedOptions.startDate = null;
            this.derivedOptions.endDate = null;
        }
        if (this.derivedOptions.singleCalendar) {
            this.derivedOptions.autoApply = true;
            this.derivedOptions.endDate = null;
        }
        if (this.derivedOptions.timePicker) {
            this.derivedOptions.autoApply = false;
        }
        if (this.derivedOptions.alwaysOpen) {
            this.derivedOptions.position = null;
        }
        if (!this.derivedOptions.displayFormat) {
            this.derivedOptions.displayFormat = this.derivedOptions.format;
        }
        if (this.derivedOptions.addTouchSupport && isTouch) {
            this.derivedOptions.alwaysOpen = false;
        }
        if (this.derivedOptions.showRanges &&
            !this.derivedOptions.preDefinedRanges) {
            this.derivedOptions.preDefinedRanges = defaults.ranges;
        }
        if (window.innerWidth > 600) {
            if (this.derivedOptions.position === 'left') {
                var spaceToRight = window.innerWidth -
                    this.elem.nativeElement.getBoundingClientRect().left;
                if (spaceToRight < 500) {
                    this.derivedOptions.position = 'right';
                }
            }
            else if (this.derivedOptions.position === 'right') {
                if (this.elem.nativeElement.getBoundingClientRect().right < 500) {
                    this.derivedOptions.position = 'left';
                }
            }
        }
    };
    Daterangepicker.prototype.setFromDate = function (value) {
        if (this.derivedOptions.noDefaultRangeSelected && !value) {
            this.fromDate = null;
            this.tempFromDate = this.getActualFromDate(value);
        }
        else {
            this.fromDate = this.getActualFromDate(value);
        }
    };
    Daterangepicker.prototype.getActualFromDate = function (value) {
        var temp;
        if ((temp = this.getValidateDayjs(value))) {
            return this.getValidateFromDate(temp);
        }
        return this.getValidateFromDate(dayjs());
    };
    Daterangepicker.prototype.setToDate = function (value) {
        if (this.derivedOptions.noDefaultRangeSelected && !value) {
            this.toDate = null;
            this.tempToDate = this.getActualToDate(value);
        }
        else {
            this.toDate = this.getActualToDate(value);
        }
    };
    Daterangepicker.prototype.getActualToDate = function (value) {
        var temp;
        if ((temp = this.getValidateDayjs(value))) {
            return this.getValidateToDate(temp);
        }
        return this.getValidateToDate(dayjs());
    };
    Daterangepicker.prototype.validateMinMaxDates = function () {
        if (this.derivedOptions) {
            if (this.derivedOptions.minDate && !this.derivedOptions.maxDate) {
                this.derivedOptions.minDate = this.getDayjs(this.derivedOptions.minDate);
            }
            if (!this.derivedOptions.minDate && this.derivedOptions.maxDate) {
                this.derivedOptions.maxDate = this.getDayjs(this.derivedOptions.maxDate);
            }
            if (this.derivedOptions.minDate && this.derivedOptions.maxDate) {
                this.derivedOptions.minDate = this.getDayjs(this.derivedOptions.minDate);
                this.derivedOptions.maxDate = this.getDayjs(this.derivedOptions.maxDate);
                if (this.derivedOptions.maxDate.isBefore(this.derivedOptions.minDate, 'date')) {
                    this.derivedOptions.minDate = null;
                    this.derivedOptions.maxDate = null;
                    console.warn('supplied minDate is after maxDate. Discarding options for minDate and maxDate');
                }
            }
            if (this.derivedOptions.minDate &&
                this.derivedOptions.minDate.format('HH:mm') === '00:00') {
                this.derivedOptions.minDate.set('hour', 0);
                this.derivedOptions.minDate.set('minute', 0);
                this.derivedOptions.minDate.set('second', 0);
            }
            if (this.derivedOptions.maxDate &&
                this.derivedOptions.maxDate.format('HH:mm') === '00:00') {
                this.derivedOptions.minDate.set('hour', 23);
                this.derivedOptions.minDate.set('minute', 59);
                this.derivedOptions.minDate.set('second', 59);
            }
        }
    };
    Daterangepicker.prototype.getValidateFromDate = function (value) {
        if (!this.derivedOptions.timePicker) {
            if (this.derivedOptions.minDate &&
                this.derivedOptions.maxDate &&
                value.isSameOrAfter(this.derivedOptions.minDate, 'date') &&
                value.isSameOrBefore(this.derivedOptions.maxDate, 'date')) {
                return value;
            }
            if (this.derivedOptions.minDate &&
                !this.derivedOptions.maxDate &&
                value.isAfter(this.derivedOptions.minDate, 'date')) {
                return value;
            }
            if (this.derivedOptions.minDate) {
                return this.derivedOptions.minDate.clone();
            }
            return dayjs();
        }
        else {
            if (this.derivedOptions.minDate &&
                this.derivedOptions.maxDate &&
                value.isSameOrAfter(this.derivedOptions.minDate, 'date') &&
                value.isSameOrBefore(this.derivedOptions.maxDate, 'date')) {
                return value;
            }
            if (this.derivedOptions.minDate &&
                !this.derivedOptions.maxDate &&
                value.isAfter(this.derivedOptions.minDate, 'date')) {
                return value;
            }
            if (this.derivedOptions.minDate) {
                return this.derivedOptions.minDate.clone();
            }
            return dayjs();
        }
    };
    Daterangepicker.prototype.getValidateToDate = function (value) {
        if (!this.derivedOptions.timePicker) {
            if ((this.derivedOptions.maxDate &&
                value.isSameOrAfter(this.fromDate, 'date'),
                value.isSameOrBefore(this.derivedOptions.maxDate, 'date'))) {
                return value;
            }
            if (this.derivedOptions.maxDate) {
                return this.derivedOptions.maxDate.clone();
            }
            return dayjs();
        }
        else {
            if ((this.derivedOptions.maxDate &&
                value.isSameOrAfter(this.fromDate, 'date'),
                value.isSameOrBefore(this.derivedOptions.maxDate, 'date'))) {
                return value;
            }
            if (this.derivedOptions.maxDate) {
                return this.derivedOptions.maxDate.clone();
            }
            return dayjs();
        }
    };
    Daterangepicker.prototype.getDayjs = function (value) {
        return dayjs(value, this.derivedOptions.format);
    };
    Daterangepicker.prototype.getValidateDayjs = function (value) {
        var dayjsValue = null;
        if (dayjs(value, this.derivedOptions.format, true).isValid()) {
            dayjsValue = dayjs(value, this.derivedOptions.format, true);
        }
        return dayjsValue;
    };
    Daterangepicker.prototype.formatFromDate = function (event) {
        if (event.target.value !== this.fromDate.format(this.derivedOptions.format)) {
            this.dateChanged({
                day: event.target.value ? this.getDayjs(event.target.value) : dayjs(),
                isLeft: true,
            });
        }
    };
    Daterangepicker.prototype.formatToDate = function (event) {
        if (event.target.value !== this.toDate.format(this.derivedOptions.format)) {
            this.dateChanged({
                day: event.target.value ? this.getDayjs(event.target.value) : dayjs(),
                isLeft: false,
            });
        }
    };
    Daterangepicker.prototype.scrollTop = function () {
        var flyout = this.elem.nativeElement.querySelector('.drp-flyout');
        flyout.scrollBy(0, 300);
    };
    Daterangepicker.prototype.dateChanged = function (data) {
        var value = data.day;
        var isLeft = data.isLeft;
        if (isLeft) {
            if (!this.derivedOptions.timePicker) {
                value = value.hour(0);
                value = value.minute(0);
                value = value.second(0);
            }
            this.fromDate = value;
            if (!this.derivedOptions.timePicker) {
                if (value.isAfter(this.toDate, 'date')) {
                    this.toDate = this.fromDate.clone();
                }
            }
            else {
                if (value.isAfter(this.toDate, this.derivedOptions.format)) {
                    this.toDate = this.fromDate.clone();
                }
            }
        }
        else {
            if (!this.derivedOptions.timePicker) {
                value = value.hour(23);
                value = value.minute(59);
                value = value.second(59);
            }
            this.toDate = value;
            this.toYear = this.toDate.get('year');
            if (!this.derivedOptions.timePicker) {
                if (value.isBefore(this.fromDate, 'date')) {
                    this.fromDate = this.toDate.clone();
                }
            }
            else {
                if (value.isBefore(this.fromDate, this.derivedOptions.format)) {
                    this.fromDate = this.toDate.clone();
                }
            }
        }
        if (this.derivedOptions.autoApply) {
            if (this.derivedOptions.singleCalendar || !isLeft) {
                this.toggleCalendars(false);
                this.setRange();
                this.emitRangeSelected();
            }
        }
        else if (!this.derivedOptions.singleCalendar &&
            this.fromDate &&
            this.fromDate.isValid() &&
            this.toDate &&
            this.toDate.isValid()) {
            this.enableApplyButton = true;
        }
        else if (this.derivedOptions.singleCalendar) {
            this.enableApplyButton = true;
        }
        this.fromMonth = this.fromDate
            ? this.fromDate.get('month')
            : this.fromMonth;
        this.toMonth = this.toDate ? this.toDate.get('month') : this.toMonth;
        this.fromYear = this.fromDate ? this.fromDate.get('year') : this.fromYear;
        if (!this.toDate && this.fromDate) {
            this.toYear = this.fromYear;
            this.toMonth = this.fromMonth;
        }
        if (this.toYear < this.fromYear) {
            this.toYear = this.fromYear;
        }
    };
    Daterangepicker.prototype.monthChanged = function (data) {
        var temp;
        if (!isTouch) {
            if (data.isLeft) {
                temp = dayjs()
                    .set('year', this.fromYear)
                    .set('month', this.fromMonth)
                    .add(data.value, 'month');
                this.fromMonth = temp.get('month');
                this.fromYear = temp.get('year');
            }
            else {
                temp = dayjs()
                    .set('year', this.toYear)
                    .set('month', this.toMonth)
                    .add(data.value, 'month');
                this.toMonth = temp.get('month');
                this.toYear = temp.get('year');
            }
        }
        else {
            if (data.isLeft) {
                this.fromMonth = data.value;
            }
            else {
                this.toMonth = data.value;
            }
        }
    };
    Daterangepicker.prototype.yearChanged = function (data) {
        if (data.isLeft) {
            this.fromYear = data.value;
        }
        else {
            this.toYear = data.value;
        }
    };
    Daterangepicker.prototype.emitRangeSelected = function () {
        var data = {};
        if (this.derivedOptions.singleCalendar) {
            data = {
                start: this.getDayjs(this.fromDate),
            };
        }
        else {
            data = {
                start: this.getDayjs(this.fromDate),
                end: this.getDayjs(this.toDate),
            };
        }
        this.enableApplyButton = false;
        this.rangeSelected.emit(data);
    };
    Daterangepicker.prototype.storeOldDates = function () {
        if (!this.areOldDatesStored) {
            this.oldFromDate = this.fromDate;
            this.oldToDate = this.toDate;
            this.areOldDatesStored = true;
        }
    };
    Daterangepicker.prototype.restoreOldDates = function () {
        this.fromDate = this.oldFromDate;
        this.toDate = this.oldToDate;
    };
    Daterangepicker.prototype.setRange = function () {
        if (this.derivedOptions.singleCalendar && this.fromDate) {
            this.range = this.fromDate.format(this.derivedOptions.displayFormat);
        }
        else if (this.fromDate && this.toDate) {
            this.range =
                this.fromDate.format(this.derivedOptions.displayFormat) +
                    ' - ' +
                    this.toDate.format(this.derivedOptions.displayFormat);
        }
        else {
            this.range = '';
        }
    };
    Daterangepicker.prototype.apply = function () {
        this.toggleCalendars(false);
        this.setRange();
        this.emitRangeSelected();
    };
    Daterangepicker.prototype.cancel = function () {
        this.restoreOldDates();
        this.toggleCalendars(false);
    };
    Daterangepicker.prototype.clear = function () {
        this.fromDate = this.toDate = null;
        this.apply();
        this.enableApplyButton = false;
    };
    Daterangepicker.prototype.applyPredefinedRange = function (data) {
        this.setFromDate(data.value.start);
        this.setToDate(data.value.end);
        this.toggleCalendars(false);
        this.emitRangeSelected();
    };
    Daterangepicker.prototype.toggleCalendars = function (value) {
        this.showCalendars = value;
        if (!value) {
            this.areOldDatesStored = false;
            this.updateCalendar();
        }
    };
    Daterangepicker.prototype.updateCalendar = function () {
        var fromDate = dayjs(this.fromDate).isValid()
            ? this.fromDate
            : this.tempFromDate;
        var toDate = dayjs(this.toDate).isValid() ? this.toDate : this.tempToDate;
        var tDate = dayjs(fromDate, this.derivedOptions.format);
        this.fromMonth = tDate.get('month');
        this.fromYear = tDate.get('year');
        tDate = dayjs(toDate, this.derivedOptions.format);
        this.toMonth = tDate.get('month');
        this.toYear = tDate.get('year');
        this.setRange();
    };
    Daterangepicker.prototype.getAriaLabel = function () {
        if (this.fromDate && this.toDate) {
            return (this.fromDate.format(this.derivedOptions.displayFormat) +
                ' to ' +
                this.toDate.format(this.derivedOptions.displayFormat));
        }
        return 'Please select a date range';
    };
    Daterangepicker.decorators = [
        { type: Component, args: [{
                    selector: 'daterangepicker',
                    template: "<div class=\"drp-wrapper {{derivedOptions.theme}}\">\n  <input class=\"{{class}} drp-input\" [attr.placeholder]=\"derivedOptions.placeholder\" type=\"text\" [ngModel]=\"range\"\n    [disabled]=\"derivedOptions.disabled\" [attr.aria-label]=\"getAriaLabel()\" [class.hidden]=\"derivedOptions.alwaysOpen\"\n    [attr.required]=\"derivedOptions.required\" [attr.readonly]=\"derivedOptions.readOnly ? true : null\" />\n  <div class=\"drp-flyout {{derivedOptions.position}}\" [ngClass]=\"{\n          hidden: !(showCalendars || derivedOptions.alwaysOpen),\n          singledatepicker: derivedOptions.singleCalendar,\n          tooltipChevron: !derivedOptions.alwaysOpen,\n          alwaysOpen: derivedOptions.alwaysOpen,\n          touch: derivedOptions.addTouchSupport,\n          fixed: !isLargeDesktop\n        }\">\n    <div class=\"drp-calendars-wrapper\">\n      <div class=\"drp-calendar-container\">\n        <span class=\"drp-selected-date\">{{fromDate | formatDate: derivedOptions.displayFormat}}</span>\n        <calendar class=\"calender\" [isLeft]=\"true\" [month]=\"fromMonth\" [year]=\"fromYear\" (scrollTop)=\"scrollTop()\"\n          (monthChanged)=\"monthChanged($event)\" (yearChanged)=\"yearChanged($event)\" (dateChanged)=\"dateChanged($event)\"\n          [format]=\"format\" [selectedFromDate]=\"fromDate\" [selectedToDate]=\"toDate\" [minDate]=\"derivedOptions.minDate\"\n          [maxDate]=\"derivedOptions.maxDate\" [inactiveBeforeStart]=\"derivedOptions.inactiveBeforeStart\"\n          [disableBeforeStart]=\"derivedOptions.disableBeforeStart\" [timePicker]=\"derivedOptions.timePicker\"\n          [singleCalendar]=\"derivedOptions.singleCalendar\" [weekStartsOn]=\"derivedOptions.weekStartsOn\"\n          [addTouchSupport]=\"derivedOptions.addTouchSupport\" [disableWeekEnds]=\"derivedOptions.disableWeekEnds\"\n          [disabledDays]=\"derivedOptions.disabledDays\" [disabledDates]=\"derivedOptions.disabledDates\"></calendar>\n      </div>\n      <div class=\"drp-calendar-container\" *ngIf=\"!derivedOptions.singleCalendar\">\n        <span class=\"drp-selected-date\">{{toDate | formatDate: derivedOptions.displayFormat}}</span>\n        <calendar class=\"calender\" [month]=\"toMonth\" [year]=\"toYear\" [format]=\"format\" (scrollTop)=\"scrollTop()\"\n          (dateChanged)=\"dateChanged($event)\" (monthChanged)=\"monthChanged($event)\" (yearChanged)=\"yearChanged($event)\"\n          [selectedFromDate]=\"fromDate\" [selectedToDate]=\"toDate\" [minDate]=\"derivedOptions.minDate\"\n          [maxDate]=\"derivedOptions.maxDate\" [inactiveBeforeStart]=\"derivedOptions.inactiveBeforeStart\"\n          [disableBeforeStart]=\"derivedOptions.disableBeforeStart\" [timePicker]=\"derivedOptions.timePicker\"\n          [weekStartsOn]=\"derivedOptions.weekStartsOn\" [addTouchSupport]=\"derivedOptions.addTouchSupport\"\n          [disableWeekEnds]=\"derivedOptions.disableWeekEnds\" [disabledDays]=\"derivedOptions.disabledDays\"\n          [disabledDates]=\"derivedOptions.disabledDates\"></calendar>\n      </div>\n    </div>\n    <div class=\"my-0 drp-controls\">\n      <div class=\"drp-flex\" [hidden]=\"derivedOptions.hideControls\">\n        <button [class.hidden]=\"derivedOptions.autoApply\" class=\"drp-btn apply\" [disabled]=\"!enableApplyButton\"\n          (click)=\"apply()\" type=\"button\">\n          Apply\n        </button>\n        <button [class.hidden]=\"derivedOptions.autoApply\" class=\"drp-btn cancel\" (click)=\"cancel()\" type=\"button\">\n          Cancel\n        </button>\n        <button [disabled]=\"!this.range\" class=\"drp-btn flat link\" (click)=\"clear()\" type=\"button\">\n          Clear\n        </button>\n      </div>\n      <div class=\"drp-flex range-controls\" *ngIf=\"derivedOptions.showRanges && !derivedOptions.singleCalendar\">\n        <button *ngFor=\"let range of derivedOptions.preDefinedRanges\" class=\"drp-btn outline\"\n          (click)=\"applyPredefinedRange(range)\" type=\"button\">\n          {{ range.name }}\n        </button>\n      </div>\n    </div>\n  </div>\n</div>\n"
                }] }
    ];
    Daterangepicker.ctorParameters = function () { return [
        { type: ElementRef }
    ]; };
    Daterangepicker.propDecorators = {
        options: [{ type: Input }],
        class: [{ type: Input }],
        rangeSelected: [{ type: Output }],
        handleOutsideClick: [{ type: HostListener, args: ['document:mousedown', ['$event'],] }, { type: HostListener, args: ['document:mouseup', ['$event'],] }, { type: HostListener, args: ['document:keyup', ['$event'],] }]
    };
    return Daterangepicker;
}());

var FormatDatePipe = (function () {
    function FormatDatePipe() {
    }
    FormatDatePipe.prototype.transform = function (value, format) {
        if (value) {
            return value.format(format);
        }
        return '';
    };
    FormatDatePipe.decorators = [
        { type: Pipe, args: [{ name: 'formatDate' },] }
    ];
    return FormatDatePipe;
}());

var ChevronLeft = (function () {
    function ChevronLeft() {
    }
    ChevronLeft.decorators = [
        { type: Component, args: [{
                    selector: 'chevronleft',
                    template: "\n    <svg\n      xmlns=\"http://www.w3.org/2000/svg\"\n      xmlns:xlink=\"http://www.w3.org/1999/xlink\"\n      version=\"1.1\"\n      id=\"Capa_1\"\n      x=\"0px\"\n      y=\"0px\"\n      width=\"16px\"\n      height=\"16px\"\n      viewBox=\"0 0 444.531 444.531\"\n      style=\"enable-background:new 0 0 444.531 444.531;\"\n      xml:space=\"preserve\"\n    >\n      <g>\n        <path\n          d=\"M213.13,222.409L351.88,83.653c7.05-7.043,10.567-15.657,10.567-25.841c0-10.183-3.518-18.793-10.567-25.835   l-21.409-21.416C323.432,3.521,314.817,0,304.637,0s-18.791,3.521-25.841,10.561L92.649,196.425   c-7.044,7.043-10.566,15.656-10.566,25.841s3.521,18.791,10.566,25.837l186.146,185.864c7.05,7.043,15.66,10.564,25.841,10.564   s18.795-3.521,25.834-10.564l21.409-21.412c7.05-7.039,10.567-15.604,10.567-25.697c0-10.085-3.518-18.746-10.567-25.978   L213.13,222.409z\"\n        />\n      </g>\n    </svg>\n  "
                }] }
    ];
    ChevronLeft.propDecorators = {
        class: [{ type: Input }]
    };
    return ChevronLeft;
}());

var DoubleChevronLeft = (function () {
    function DoubleChevronLeft() {
    }
    DoubleChevronLeft.decorators = [
        { type: Component, args: [{
                    selector: 'doublechevronleft',
                    template: "\n    <svg\n      xmlns=\"http://www.w3.org/2000/svg\"\n      xmlns:xlink=\"http://www.w3.org/1999/xlink\"\n      version=\"1.1\"\n      id=\"Layer_1\"\n      x=\"0px\"\n      y=\"0px\"\n      viewBox=\"0 0 407.436 407.436\"\n      style=\"enable-background:new 0 0 407.436 407.436;\"\n      xml:space=\"preserve\"\n      width=\"16px\"\n      height=\"16px\"\n    >\n      <g>\n        <polygon\n          points=\"266.452,21.178 245.204,0 42.149,203.718 245.204,407.436 266.452,386.258 84.507,203.718  \"\n        />\n        <polygon\n          points=\"365.286,21.178 344.038,0 140.983,203.718 344.038,407.436 365.286,386.258 183.341,203.718  \"\n        />\n      </g>\n    </svg>\n  "
                }] }
    ];
    DoubleChevronLeft.propDecorators = {
        class: [{ type: Input }]
    };
    return DoubleChevronLeft;
}());

dayjs.extend(isSameOrAfter);
dayjs.extend(isSameOrBefore);
dayjs.extend(customParser);
var TimePicker = (function () {
    function TimePicker() {
        this.options = new Timepicker();
        this.timeChanged = new EventEmitter();
    }
    TimePicker.prototype.ngOnInit = function () {
        this.meridiem = this.isLeft
            ? this.selectedFromDate.format('A')
            : this.selectedToDate.format('A');
        if (!this.options.minuteInterval ||
            this.options.minuteInterval % 60 === 0) {
            this.options.minuteInterval = 1;
        }
        this.options.minuteInterval = this.options.minuteInterval % 60;
    };
    TimePicker.prototype.ngOnChanges = function (changes) {
        this.selectedFromDate = changes['selectedFromDate']
            ? dayjs(changes['selectedFromDate'].currentValue, this.format)
            : this['selectedFromDate'];
        this.selectedToDate = changes['selectedToDate']
            ? dayjs(changes['selectedToDate'].currentValue, this.format)
            : this['selectedToDate'];
        this.maxDate = changes['maxDate']
            ? dayjs(changes['maxDate'].currentValue, this.format)
            : this['maxDate'];
        this.minDate = changes['minDate']
            ? dayjs(changes['minDate'].currentValue, this.format)
            : this['minDate'];
        this.meridiem = this.isLeft
            ? this.selectedFromDate.format('A')
            : this.selectedToDate.format('A');
    };
    TimePicker.prototype.getCurrentHour = function () {
        var modFactor = this.options.twentyFourHourFormat ? 24 : 12;
        var currentHour = (this.isLeft
            ? this.selectedFromDate.get('hour')
            : this.selectedToDate.get('hour')) % modFactor;
        return isNaN(currentHour)
            ? '&mdash;'
            : currentHour > 9
                ? currentHour
                : '0' + currentHour;
    };
    TimePicker.prototype.getCurrentMinute = function () {
        var currentMinute = this.isLeft
            ? this.selectedFromDate.get('minute')
            : this.selectedToDate.get('minute');
        return isNaN(currentMinute)
            ? '&mdash;'
            : currentMinute > 9
                ? currentMinute
                : '0' + currentMinute;
    };
    TimePicker.prototype.isValidToAddMinute = function (value) {
        var possibleNewValue;
        var possibleSelectedDate;
        if (this.isLeft) {
            possibleNewValue = this.selectedFromDate.get('minute') + value;
            possibleSelectedDate = this.selectedFromDate.clone().add(value, 'minute');
        }
        else {
            possibleNewValue = this.selectedToDate.get('minute') + value;
            possibleSelectedDate = this.selectedToDate.clone().add(value, 'minute');
        }
        var retValue = possibleNewValue < 60 && possibleNewValue >= 0;
        if (this.minDate.isValid()) {
            retValue = retValue && possibleSelectedDate.isSameOrAfter(this.minDate);
        }
        if (this.maxDate.isValid()) {
            retValue = retValue && possibleSelectedDate.isSameOrBefore(this.maxDate);
        }
        return retValue;
    };
    TimePicker.prototype.isValidToAddHour = function (value) {
        var possibleNewValue;
        var possibleSelectedDate;
        if (this.isLeft) {
            possibleNewValue = this.selectedFromDate.get('hour') + value;
            possibleSelectedDate = this.selectedFromDate.clone().add(value, 'hour');
        }
        else {
            possibleNewValue = this.selectedToDate.get('hour') + value;
            possibleSelectedDate = this.selectedToDate.clone().add(value, 'hour');
        }
        var retValue = possibleNewValue < 24 && possibleNewValue >= 0;
        if (this.minDate.isValid()) {
            retValue = retValue && possibleSelectedDate.isSameOrAfter(this.minDate);
        }
        if (this.maxDate.isValid()) {
            retValue = retValue && possibleSelectedDate.isSameOrBefore(this.maxDate);
        }
        return retValue;
    };
    TimePicker.prototype.addHour = function (value) {
        var extraPadding = this.meridiem === 'AM' ? -12 : 12;
        if (this.isLeft) {
            this.selectedFromDate = this.selectedFromDate.set('hour', (+this.selectedFromDate.get('hour') + value + extraPadding) % 24);
        }
        else {
            this.selectedToDate = this.selectedToDate.set('hour', (+this.selectedToDate.get('hour') + value + extraPadding) % 24);
        }
        this.triggerTimeChanged();
    };
    TimePicker.prototype.addMinute = function (value) {
        if (this.isLeft) {
            this.selectedFromDate = this.selectedFromDate.set('minute', (this.selectedFromDate.get('minute') + value) % 60);
        }
        else {
            this.selectedToDate = this.selectedToDate.set('minute', (this.selectedToDate.get('minute') + value) % 60);
        }
        this.triggerTimeChanged();
    };
    TimePicker.prototype.triggerTimeChanged = function () {
        this.isLeft
            ? this.timeChanged.emit(this.selectedFromDate)
            : this.timeChanged.emit(this.selectedToDate);
    };
    TimePicker.prototype.toggleAMPM = function () {
        if (this.meridiem === 'AM') {
            this.meridiem = 'PM';
        }
        else if (this.meridiem === 'PM') {
            this.meridiem = 'AM';
        }
        this.addHour(0);
    };
    TimePicker.decorators = [
        { type: Component, args: [{
                    selector: 'timepicker',
                    template: "<div class=\"drp-flex\"\n  [ngClass]=\"{'col-md-offset-4': options.twentyFourHourFormat, 'col-md-offset-3': !options.twentyFourHourFormat}\">\n  <div class=\"drp-flex drp-column\">\n    <button aria-label=\"Increment hour by 1\" class=\"drp-btn flat up\" [ngClass]=\"{'disabled': !isValidToAddHour(1)}\"\n      (click)=\"addHour(1)\">\n      <chevronleft></chevronleft>\n    </button>\n    <span><b [innerHTML]=\"getCurrentHour()\"></b></span>\n    <button aria-label=\"Decrement hour by 1\" class=\"drp-btn flat down\" [ngClass]=\"{'disabled': !isValidToAddHour(-1)}\"\n      (click)=\"addHour(-1)\">\n      <chevronleft></chevronleft>\n    </button>\n  </div>\n  <sub>\n    <b>h</b>\n  </sub>\n  <div class=\"drp-flex drp-column\">\n    <button aria-label=\"increment minute by one step\" class=\"drp-btn flat up\"\n      [ngClass]=\"{'disabled': !isValidToAddMinute(options.minuteInterval)}\" (click)=\"addMinute(options.minuteInterval)\">\n      <chevronleft></chevronleft>\n    </button>\n    <span><b [innerHTML]=\"getCurrentMinute()\" (mouseWheelUp)=\"addMinute(options.minuteInterval)\"></b></span>\n    <button aria-label=\"decrement minute by one step\" class=\"drp-btn flat down\"\n      [ngClass]=\"{'disabled': !isValidToAddMinute(-1 * options.minuteInterval)}\"\n      (click)=\"addMinute(-1 * options.minuteInterval)\">\n      <chevronleft></chevronleft>\n    </button>\n  </div>\n  <sub>\n    <b>m</b>\n  </sub>\n  <div class=\"drp-flex drp-column ml-2\" *ngIf=\"!options.twentyFourHourFormat\">\n    <button class=\"drp-btn flat up\" (click)=\"toggleAMPM()\">\n      <chevronleft></chevronleft>\n    </button>\n    <span><b>{{meridiem}}</b></span>\n    <button class=\"drp-btn flat down\" (click)=\"toggleAMPM()\">\n      <chevronleft></chevronleft>\n    </button>\n  </div>\n</div>\n"
                }] }
    ];
    TimePicker.propDecorators = {
        options: [{ type: Input }],
        selectedFromDate: [{ type: Input }],
        selectedToDate: [{ type: Input }],
        minDate: [{ type: Input }],
        maxDate: [{ type: Input }],
        format: [{ type: Input }],
        isLeft: [{ type: Input }],
        timeChanged: [{ type: Output }]
    };
    return TimePicker;
}());

var DatetimerangepickerModule = (function () {
    function DatetimerangepickerModule() {
    }
    DatetimerangepickerModule.decorators = [
        { type: NgModule, args: [{
                    imports: [FormsModule, CommonModule],
                    declarations: [
                        Daterangepicker,
                        Calendar,
                        TimePicker,
                        FormatDatePipe,
                        DoubleChevronLeft,
                        ChevronLeft,
                    ],
                    exports: [Daterangepicker],
                },] }
    ];
    return DatetimerangepickerModule;
}());

var dayjs$1 = require('dayjs');
var isSameOrAfter$1 = require('dayjs/plugin/isSameOrAfter');
dayjs$1.extend(isSameOrAfter$1);
var isSameOrBefore$1 = require('dayjs/plugin/isSameOrBefore');
dayjs$1.extend(isSameOrBefore$1);
var customParser$1 = require('dayjs/plugin/customParseFormat');
dayjs$1.extend(customParser$1);
var isoWeek = require('dayjs/plugin/isoWeek');
dayjs$1.extend(isoWeek);
var arraySupport = require('dayjs/plugin/arraySupport');
dayjs$1.extend(arraySupport);

export { DatetimerangepickerModule, DateRange, DateChanged, YearMonthChanged, MonthNameValue, DefinedDateRange, Timepicker, YearsGrid, Options, Calendar as ɵb, Daterangepicker as ɵa, FormatDatePipe as ɵd, ChevronLeft as ɵf, DoubleChevronLeft as ɵe, TimePicker as ɵc };

//# sourceMappingURL=angular-datetimerangepicker.js.map